OrageTrayIcon{
   background-color: rgb(239, 235, 230);
   border-color: black;
   border-radius: 16px;
   border-top-width: 2px;
   border-right-width: 5px;
   border-bottom-width: 5px;
   border-left-width: 2px;
   border-style: solid;
   font-size: 85px;
}

OrageTrayIcon > row-1{
   font-family: Ariel;
   font-size: 41%;
   color: blue;
}

OrageTrayIcon > row-2{
   font-family: Sans;
   font-weight: bold;
   font-size: 100%;
   color: red;
}

OrageTrayIcon > row-3{
   font-family: Ariel;
   font-weight: bold;
   font-size: 44%;
   color: blue;
}

#OrageWeekWindow #today{
   background: gold;
   font-weight: bold;
   border-width: 1px;
}

#OrageWeekWindow #sunday{
   color: red;
}

#OrageWeekWindow #all-day-event{
   background: lightgray;
}

#OrageWeekWindow label#odd-hours{
   background: lightgray;
   padding: 4px
}

#OrageWeekWindow #even-hours{
   background: rgb(239, 235, 230);
   padding: 4px
}

#OrageWeekWindow #hour-line{
   background: white;
   min-width: 3px;
}

#OrageWeekWindow label#hour-line-occupied{
   background: black;
   min-width: 3px;
}

#OrageWindow #todo-completed{
   color: red;
}

#OrageWindow #todo-actual-now{
   color: blue;
}
